@@ -1,7 +1,7 @@
 /**********************************************************************
  * plugin_debugger.c	- Language-independent parts of debugger
  *
- * Copyright (c) 2004-2018 EnterpriseDB Corporation. All Rights Reserved.
+ * Copyright (c) 2004-2024 EnterpriseDB Corporation. All Rights Reserved.
  *
  * Licensed under the Artistic License v2.0, see
  *		https://opensource.org/licenses/artistic-license-2.0
@@ -185,7 +185,7 @@ static void pldebugger_shmem_request( void )
  * CREATE OR REPLACE FUNCTION pldbg_oid_debug( functionOID OID ) RETURNS INTEGER AS 'pldbg_oid_debug' LANGUAGE C;
  */
 
-Datum pldbg_oid_debug(PG_FUNCTION_ARGS);
+PGDLLEXPORT Datum pldbg_oid_debug(PG_FUNCTION_ARGS);
 PG_FUNCTION_INFO_V1(pldbg_oid_debug);
 
 Datum pldbg_oid_debug(PG_FUNCTION_ARGS)
